@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::HashEditor;
-$Config::Model::Tk::HashEditor::VERSION = '1.356';
+$Config::Model::Tk::HashEditor::VERSION = '1.357';
 use strict;
 use warnings;
 use Carp;
@@ -90,7 +90,8 @@ sub Populate {
     );
     $tklist->pack( @fbe1, -side => 'left' );
     $cw->Advertise( tklist => $tklist );
-    $cw->insert( end => $hash->fetch_all_indexes );
+
+    $cw->reset_value;
 
     my $item_frame = $cw->Frame(qw/-borderwidth 1 -relief groove/)->pack( @fx, -anchor => 'n' );
 
@@ -233,6 +234,13 @@ sub Populate {
     $cw->Tk::Frame::Populate($args);
 }
 
+sub reset_value {
+    my $cw = shift ;
+    $cw->Subwidget('tklist')->delete( 0, 'end' );
+    $cw->insert( end => $cw->{hash}->fetch_all_indexes );
+}
+
+
 # the following function is used to make multi-line keys (like Files
 # entries in Debian copyright files) more manageable: LF are replaced
 # by \n to enable editing a multi line entry in a Tk::Entry.
